@@ -15,7 +15,7 @@ from urllib.parse import parse_qsl, quote, urlencode, urljoin, urlsplit
 import httpx
 
 
-__version__ = "0.25.7"
+__version__ = "0.25.8"
 __project__ = "aioauth-client"
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __license__ = "MIT"
@@ -299,7 +299,7 @@ class OAuth2Client(Client):
         if access_token:
             headers.setdefault('Authorization', 'Bearer %s' % access_token)
 
-        return self._request(method, url, headers=headers, **options)
+        return self._request(method, url, headers=headers, params=params, **options)
 
     async def get_access_token(self, code: str, redirect_uri: str = None,
                                headers: t.Dict = None, **payload) -> t.Tuple[str, t.Any]:
